==> cordova-plugin-ws1intelligence-0.1.1.tgz: package/platforms/android/com/ws1intelligence/plugin/CDVWS1Intelligence.java <==
//  Copyright 2021 VMWare

package com.ws1intelligence.plugin;

import java.net.URL;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;

import org.apache.cordova.CallbackContext;
import org.apache.cordova.CordovaInterface;
import org.apache.cordova.CordovaPlugin;
import org.apache.cordova.CordovaWebView;
import org.apache.cordova.PluginResult;
import org.apache.cordova.PluginResult.Status;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import android.content.Context;
import android.content.res.Resources;

import com.crittercism.app.Crittercism;
import com.crittercism.error.CRXMLHttpRequestException;

public class CDVWS1Intelligence extends CordovaPlugin {
    public static final String ACTION_INIT = "ws1IntelligenceInit";
    public static final String ACTION_ADD_BREADCRUMB = "ws1IntelligenceLeaveBreadcrumb";
    public static final String ACTION_SET_USERNAME = "ws1IntelligenceSetUsername";
    public static final String ACTION_LOG_HANDLED_EXCEPTION = "ws1IntelligenceLogHandledException";
    public static final String ACTION_LOG_CRASH_EXCEPTION = "ws1IntelligenceLogUnhandledException";
    public static final String ACTION_LOG_NETWORK_REQUEST = "ws1IntelligenceLogNetworkRequest";
    public static final String ACTION_BEGIN_USERFLOW = "ws1IntelligenceBeginUserFlow";
    public static final String ACTION_END_USERFLOW = "ws1IntelligenceEndUserFlow";
    public static final String ACTION_FAIL_USERFLOW = "ws1IntelligenceFailUserFlow";
    public static final String ACTION_CANCEL_USERFLOW = "ws1IntelligenceCancelUserFlow";

    public static final String APPLICATION_ID = "cr_app_id";
    public static final String STRING = "string";

    private ExecutorService executor = Executors.newSingleThreadExecutor();
    private String packageName;

    @Override
    public void initialize(CordovaInterface cordova, CordovaWebView webView) {
        super.initialize(cordova, webView);
    }

    @Override
    public boolean execute(String action, final JSONArray args,
                           CallbackContext callbackContext) throws JSONException {
        try {
            if (ACTION_INIT.equals(action)) {
                return executeInit(action, args, callbackContext);
            } else if (ACTION_ADD_BREADCRUMB.equals(action)) {
                return executeLeaveBreadcrumb(action, args, callbackContext);
            } else if (ACTION_SET_USERNAME.equals(action)) {
                return executeSetUsername(action, args, callbackContext);
            } else if (ACTION_LOG_HANDLED_EXCEPTION.equals(action)) {
                return executeLogHandledException(action, args, callbackContext);
            } else if (ACTION_LOG_CRASH_EXCEPTION.equals(action)) {
                return executeLogCrashException(action, args, callbackContext);
            } else if (ACTION_LOG_NETWORK_REQUEST.equals(action)) {
                return executeLogNetworkRequest(action, args, callbackContext);
            } else if (ACTION_BEGIN_USERFLOW.equals(action)) {
                return executeBeginUserFlow(action, args, callbackContext);
            } else if (ACTION_END_USERFLOW.equals(action)) {
                return executeEndUserFlow(action, args, callbackContext);
            } else if (ACTION_FAIL_USERFLOW.equals(action)) {
                return executeFailUserFlow(action, args, callbackContext);
            } else if (ACTION_CANCEL_USERFLOW.equals(action)) {
                return executeCancelUserFlow(action, args, callbackContext);
            }
            return false;
        } catch (ThreadDeath td) {
            throw td;
        } catch (Throwable t) {
            //Crittercism.logHandledException(t);
            return false;
        }
    }

    private boolean executeInit(String action, final JSONArray args,
                            CallbackContext callbackContext) throws JSONException {
        final JSONObject argsDict = args.getJSONObject(0);
        final String appID = argsDict.getString("androidAppID");
        final Context context = this.cordova.getActivity();
        executor.execute(new Runnable() {
            @Override
            public void run() {
                Crittercism.initialize(context, appID);
            }
        });
        return true;
    }
    
    private boolean executeLeaveBreadcrumb(String action, final JSONArray args,
                               CallbackContext callbackContext) throws JSONException {
        final String breadcrumb = args.getString(0);
        executor.execute(new Runnable() {
            @Override
            public void run() {
                Crittercism.leaveBreadcrumb(breadcrumb);
            }
        });
        return true;
    }

    private boolean executeSetUsername(String action, final JSONArray args,
                               CallbackContext callbackContext) throws JSONException {
        final String username = args.getString(0);
        executor.execute(new Runnable() {
            @Override
            public void run() {
                Crittercism.setUsername(username);
            }
        });
        return true;
    }

    private boolean executeLogHandledException(String action, final JSONArray args,
                               CallbackContext callbackContext) throws JSONException {
        final String name = args.getString(0);
        final String msg = args.getString(1);
        final String stack = args.getString(2);
        executor.execute(new Runnable() {
            @Override
            public void run() {
                //Crittercism.logHandledException(name, msg, stack);
            }
        });
        return true;
    }

    private boolean executeLogCrashException(String action, final JSONArray args,
                               CallbackContext callbackContext) throws JSONException {
        final String msg = args.getString(0);
        final String stack = args.getString(1);
        executor.execute(new Runnable() {
            @Override
            public void run() {
                //Crittercism.logCrashException(msg, stack);
            }
        });
        return true;
    }

    private boolean executeLogNetworkRequest(String action, final JSONArray args,
                               CallbackContext callbackContext) throws JSONException {
        // I don't believe manually logging network requests is meant to be supported.
        // It doesn't appear on the docs and should this be the case, we expect the
        // error value to be an 'int' between 600 and 604 than a user supplied string.
        final String method = args.getString(0);
        final String urlStr = args.getString(1);
        final long responseTime = args.getLong(2);
        final long bytesRead = args.getLong(3);
        final long bytesSent = args.getLong(4);
        final int responseCode = args.getInt(5);
        int errorCode = 0;
        if (!args.isNull(6)) {
            errorCode = args.getInt(6);
        };
        final int finalErrorCode = errorCode; // Keep the compiler happy.
        executor.execute(new Runnable() {
            @Override
            public void run() {
                //Crittercism.logNetworkRequest(method, urlStr, responseTime, bytesRead, bytesSent, responseCode, finalErrorCode);
            }
        });
        return true;
    }

    private boolean executeBeginUserFlow(String action, final JSONArray args,
                               CallbackContext callbackContext) throws JSONException {
        final String userFlow = args.getString(0);
        executor.execute(new Runnable() {
            @Override
            public void run() {
                Crittercism.beginUserFlow(userFlow);
            }
        });
        return true;
    }

    private boolean executeEndUserFlow(String action, final JSONArray args,
                               CallbackContext callbackContext) throws JSONException {
        final String userFlow = args.getString(0);
        executor.execute(new Runnable() {
            @Override
            public void run() {
                Crittercism.endUserFlow(userFlow);
            }
        });
        return true;
    }

    private boolean executeFailUserFlow(String action, final JSONArray args,
                               CallbackContext callbackContext) throws JSONException {
        final String userFlow = args.getString(0);
        executor.execute(new Runnable() {
            @Override
            public void run() {
                Crittercism.failUserFlow(userFlow);
            }
        });
        return true;
    }

    private boolean executeCancelUserFlow(String action, final JSONArray args,
                               CallbackContext callbackContext) throws JSONException {
        final String userFlow = args.getString(0);
        executor.execute(new Runnable() {
            @Override
            public void run() {
                Crittercism.cancelUserFlow(userFlow);
            }
        });
        return true;
    }
}

==> cordova-plugin-ws1intelligence-1.0.0.tgz: package/platforms/android/com/ws1intelligence/plugin/CDVWS1Intelligence.java <==
//  Copyright 2021 VMWare

package com.ws1intelligence.plugin;

import java.util.concurrent.Callable;
import java.util.concurrent.ExecutionException;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;

import org.apache.cordova.CallbackContext;
import org.apache.cordova.CordovaInterface;
import org.apache.cordova.CordovaPlugin;
import org.apache.cordova.CordovaWebView;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import org.apache.cordova.PluginResult;
import org.apache.cordova.PluginResult.Status;

import android.content.Context;
import android.location.Location;

import com.crittercism.app.Crittercism;
import com.crittercism.app.CrittercismConfig;

public class CDVWS1Intelligence extends CordovaPlugin {
    public static final String ACTION_INIT = "ws1IntelligenceInit";
    public static final String ACTION_ADD_BREADCRUMB = "ws1IntelligenceLeaveBreadcrumb";
    public static final String ACTION_SET_USERNAME = "ws1IntelligenceSetUsername";
    public static final String ACTION_LOG_HANDLED_EXCEPTION = "ws1IntelligenceLogHandledException";
    public static final String ACTION_LOG_CRASH_EXCEPTION = "ws1IntelligenceLogUnhandledException";
    public static final String ACTION_LOG_NETWORK_REQUEST = "ws1IntelligenceLogNetworkRequest";
    public static final String ACTION_BEGIN_USERFLOW = "ws1IntelligenceBeginUserFlow";
    public static final String ACTION_END_USERFLOW = "ws1IntelligenceEndUserFlow";
    public static final String ACTION_FAIL_USERFLOW = "ws1IntelligenceFailUserFlow";
    public static final String ACTION_CANCEL_USERFLOW = "ws1IntelligenceCancelUserFlow";
    public static final String ACTION_LOG_LOCATION = "ws1IntelligenceLogLocation";
    public static final String ACTION_DID_CRASH_ON_LAST_LOAD = "ws1IntelligenceDidCrashOnLastLoad";
    public static final String ACTION_SET_OPT_OUT_STATUS = "ws1IntelligenceSetOptOutStatus";
    public static final String ACTION_GET_OPT_OUT_STATUS = "ws1IntelligenceGetOptOutStatus";



    public static final String APPLICATION_ID = "cr_app_id";
    public static final String STRING = "string";

    private ExecutorService executor = Executors.newSingleThreadExecutor();
    private String packageName;

    @Override
    public void initialize(CordovaInterface cordova, CordovaWebView webView) {
        super.initialize(cordova, webView);
    }

    @Override
    public boolean execute(String action, final JSONArray args,
                           CallbackContext callbackContext) throws JSONException {
        try {
            if (ACTION_INIT.equals(action)) {
                return executeInit(action, args, callbackContext);
            } else if (ACTION_ADD_BREADCRUMB.equals(action)) {
                return executeLeaveBreadcrumb(action, args, callbackContext);
            } else if (ACTION_SET_USERNAME.equals(action)) {
                return executeSetUsername(action, args, callbackContext);
            } else if (ACTION_LOG_HANDLED_EXCEPTION.equals(action)) {
                return executeLogHandledException(action, args, callbackContext);
            } else if (ACTION_LOG_CRASH_EXCEPTION.equals(action)) {
                return executeLogCrashException(action, args, callbackContext);
            } else if (ACTION_LOG_NETWORK_REQUEST.equals(action)) {
                return executeLogNetworkRequest(action, args, callbackContext);
            } else if (ACTION_BEGIN_USERFLOW.equals(action)) {
                return executeBeginUserFlow(action, args, callbackContext);
            } else if (ACTION_END_USERFLOW.equals(action)) {
                return executeEndUserFlow(action, args, callbackContext);
            } else if (ACTION_FAIL_USERFLOW.equals(action)) {
                return executeFailUserFlow(action, args, callbackContext);
            } else if (ACTION_CANCEL_USERFLOW.equals(action)) {
                return executeCancelUserFlow(action, args, callbackContext);
            } else if (ACTION_LOG_LOCATION.equals(action)) {
                return executeLogLocation(action, args, callbackContext);
            } else if (ACTION_DID_CRASH_ON_LAST_LOAD.equals(action)) {
                return executeDidCrashOnLastLoad(action, args, callbackContext);
            } else if (ACTION_SET_OPT_OUT_STATUS.equals(action)) {
                return executeSetOptOutStatus(action, args, callbackContext);
            } else if (ACTION_GET_OPT_OUT_STATUS.equals(action)) {
                return executeGetOptOutStatus(action, args, callbackContext);
            }
            return false;
        } catch (ThreadDeath td) {
            throw td;
        } catch (Throwable t) {
            //Crittercism.logHandledException(t);
            return false;
        }
    }

    private boolean executeInit(String action, final JSONArray args,
                            CallbackContext callbackContext) throws JSONException {
        final JSONObject argsDict = args.getJSONObject(0);
        final String appID = argsDict.getString("androidAppID");
        final Context context = this.cordova.getActivity();
        executor.execute(new Runnable() {
            @Override
            public void run() {
                CrittercismConfig crittercismConfig = new CrittercismConfig();
                Crittercism.initialize(context, appID,crittercismConfig);
            }
        });
        return true;
    }
    
    private boolean executeLeaveBreadcrumb(String action, final JSONArray args,
                               CallbackContext callbackContext) throws JSONException {
        final String breadcrumb = args.getString(0);
        executor.execute(new Runnable() {
            @Override
            public void run() {
                Crittercism.leaveBreadcrumb(breadcrumb);
            }
        });
        return true;
    }

    private boolean executeSetUsername(String action, final JSONArray args,
                               CallbackContext callbackContext) throws JSONException {
        final String username = args.getString(0);
        executor.execute(new Runnable() {
            @Override
            public void run() {
                Crittercism.setUsername(username);
            }
        });
        return true;
    }

    private boolean executeLogHandledException(String action, final JSONArray args,
                               CallbackContext callbackContext) throws JSONException {
        final String name = args.getString(0);
        final String msg = args.getString(1);
        final String stack = args.getString(2);
        executor.execute(new Runnable() {
            @Override
            public void run() {
                Crittercism.logPluginException(name, msg, stack,2);
            }
        });
        return true;
    }

    private boolean executeLogCrashException(String action, final JSONArray args,
                               CallbackContext callbackContext) throws JSONException {
        final String msg = args.getString(0);
        final String stack = args.getString(1);
        executor.execute(new Runnable() {
            @Override
            public void run() {
                Crittercism.logPluginCrashException(msg, stack,2);
            }
        });
        return true;
    }

    private boolean executeLogNetworkRequest(String action, final JSONArray args,
                               CallbackContext callbackContext) throws JSONException {
        // I don't believe manually logging network requests is meant to be supported.
        // It doesn't appear on the docs and should this be the case, we expect the
        // error value to be an 'int' between 600 and 604 than a user supplied string.
        final String method = args.getString(0);
        final String urlStr = args.getString(1);
        final long responseTime = args.getLong(2);
        final long bytesRead = args.getLong(3);
        final long bytesSent = args.getLong(4);
        final int responseCode = args.getInt(5);
        int errorCode = 0;
        if (!args.isNull(6)) {
            errorCode = args.getInt(6);
        };
        final int finalErrorCode = errorCode;
        executor.execute(new Runnable() {
            @Override
            public void run() {
                Crittercism.logNetworkRequest(method, urlStr, responseTime, bytesRead, bytesSent, responseCode, finalErrorCode);
            }
        });
        return true;
    }

    private boolean executeBeginUserFlow(String action, final JSONArray args,
                               CallbackContext callbackContext) throws JSONException {
        final String userFlow = args.getString(0);
        executor.execute(new Runnable() {
            @Override
            public void run() {
                Crittercism.beginUserFlow(userFlow);
            }
        });
        return true;
    }

    private boolean executeEndUserFlow(String action, final JSONArray args,
                               CallbackContext callbackContext) throws JSONException {
        final String userFlow = args.getString(0);
        executor.execute(new Runnable() {
            @Override
            public void run() {
                Crittercism.endUserFlow(userFlow);
            }
        });
        return true;
    }

    private boolean executeFailUserFlow(String action, final JSONArray args,
                               CallbackContext callbackContext) throws JSONException {
        final String userFlow = args.getString(0);
        executor.execute(new Runnable() {
            @Override
            public void run() {
                Crittercism.failUserFlow(userFlow);
            }
        });
        return true;
    }

    private boolean executeCancelUserFlow(String action, final JSONArray args,
                               CallbackContext callbackContext) throws JSONException {
        final String userFlow = args.getString(0);
        executor.execute(new Runnable() {
            @Override
            public void run() {
                Crittercism.cancelUserFlow(userFlow);
            }
        });
        return true;
    }

    private boolean executeLogLocation(String action, final JSONArray args,
                                       CallbackContext callbackContext)throws JSONException {
        final double latitude = args.getDouble(0);
        final double longitude = args.getDouble(1);
        Location location = new Location("Crittercism");
        location.setLatitude(latitude);
        location.setLongitude(longitude);
        executor.execute(new Runnable() {
            @Override
            public void run() {
                Crittercism.updateLocation(location);
            }
        });
        return true;
    }

    private boolean executeDidCrashOnLastLoad(String action, final JSONArray args,
                                       CallbackContext callbackContext)throws JSONException {
        try {
            sendResult(executor.submit(new Callable<Boolean>() {
                @Override
                public Boolean call() {
                    return Crittercism.didCrashOnLastLoad();
                }
            }).get(),callbackContext);
            return true;
        } catch (ExecutionException e) {
            e.printStackTrace();
            return false;
        } catch (InterruptedException e) {
            e.printStackTrace();
            return false;
        }
    }

    private boolean executeGetOptOutStatus(String action, final JSONArray args,
                                              CallbackContext callbackContext)throws JSONException {
        try {
            sendResult(executor.submit(new Callable<Boolean>() {
                @Override
                public Boolean call() {
                    return Crittercism.getOptOutStatus();
                }
            }).get(),callbackContext);

        } catch (ExecutionException e) {
            e.printStackTrace();
            return false;
        } catch (InterruptedException e) {
            e.printStackTrace();
            return false;
        }
        return true;
    }

    private void sendResult(boolean result, CallbackContext callbackContext) {
        try {
            callbackContext.sendPluginResult(new PluginResult(Status.OK, result));
        } catch (Exception e) {
            sendError(callbackContext);
        }
    }


    private void sendError(CallbackContext callbackContext) {
        callbackContext.sendPluginResult(new PluginResult(Status.ERROR));
    }

    private boolean executeSetOptOutStatus(String action, final JSONArray args,
                                              CallbackContext callbackContext)throws JSONException {
        final boolean optOutStatus = args.getBoolean(0);
        executor.execute(new Runnable() {
            @Override
            public void run() {
                Crittercism.setOptOutStatus(optOutStatus);
            }
        });
        return true;
    }
}
